Skip to contents

Returns the precision mode used when constructing new aMatrix objects that do not specify their own precision.

Usage

amatrix_default_precision()

Value

Character string, either "strict" (double precision) or "fast" (single/mixed precision).

Examples

amatrix_default_precision()
#> [1] "strict"