Computes the Kronecker product \(A \otimes B\) and returns the result as an adgeMatrix.
Accepts plain matrices or any aMatrix subclass.
For a lazy variant that avoids forming the full product see
kron_matrix.
Computes the Kronecker product \(A \otimes B\) and returns the result as an adgeMatrix.
Accepts plain matrices or any aMatrix subclass.
For a lazy variant that avoids forming the full product see
kron_matrix.