Compute row or column sums of a matrix or aMatrix, dispatching
to an accelerated backend when one is available.
Examples
m <- adgeMatrix(matrix(1:12, 3, 4))
rowsums(m)
#> [1] 22 26 30
colsums(m)
#> [1] 6 15 24 33
Compute row or column sums of a matrix or aMatrix, dispatching
to an accelerated backend when one is available.
m <- adgeMatrix(matrix(1:12, 3, 4))
rowsums(m)
#> [1] 22 26 30
colsums(m)
#> [1] 6 15 24 33