R/backend-registry.R
amatrix_fallback_log_reset.Rd
Resets the fallback log to empty. Typically called at the start of a test block to isolate the assertion that the log is empty after a clean run.
amatrix_fallback_log_reset()
Invisibly, NULL.
NULL
amatrix_fallback_log