Compute row or column sums and means for an adgeMatrix, dispatching
through the amatrix backend when GPU acceleration is available.
Examples
A <- adgeMatrix(matrix(1:12, 3, 4))
rowSums(A)
#> [1] 22 26 30
colMeans(A)
#> [1] 2 5 8 11
Compute row or column sums and means for an adgeMatrix, dispatching
through the amatrix backend when GPU acceleration is available.
A <- adgeMatrix(matrix(1:12, 3, 4))
rowSums(A)
#> [1] 22 26 30
colMeans(A)
#> [1] 2 5 8 11