Compute row or column means of a matrix or aMatrix, dispatching
to an accelerated backend when one is available.
Examples
m <- matrix(1:12, 3, 4)
rowmeans(m)
#> [1] 5.5 6.5 7.5
colmeans(m)
#> [1] 2 5 8 11
Compute row or column means of a matrix or aMatrix, dispatching
to an accelerated backend when one is available.
m <- matrix(1:12, 3, 4)
rowmeans(m)
#> [1] 5.5 6.5 7.5
colmeans(m)
#> [1] 2 5 8 11